/* 
 * Copyright (C) 2000-2001 the xine project
 * 
 * This file is part of xine, a unix video player.
 * 
 * xine is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * xine is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
 *
 * $Id: widget_types.h,v 1.8 2001/11/26 10:21:26 f1rmb Exp $
 *
 */

#ifndef HAVE_XITK_WIDGET_TYPES_H
#define HAVE_XITK_WIDGET_TYPES_H

#define WIDGET_TYPE_GROUP         0xFFFF8000

#define WIDGET_TYPE_BUTTON        0x00000001
#define WIDGET_TYPE_LABELBUTTON   0x00000002
#define WIDGET_TYPE_SLIDER        0x00000004
#define WIDGET_TYPE_LABEL         0x00000008
#define WIDGET_TYPE_CHECKBOX      0x00000010
#define WIDGET_TYPE_IMAGE         0x00000020
#define WIDGET_TYPE_BROWSER       0x00000040
#define WIDGET_TYPE_FILEBROWSER   0x00000080
#define WIDGET_TYPE_MRLBROWSER    0x00000100
#define WIDGET_TYPE_INPUTTEXT     0x00000200
#define WIDGET_TYPE_COMBO         0x00000400
#define WIDGET_TYPE_TABS          0x00000800
#define WIDGET_TYPE_INTBOX        0x00001000

#endif

